Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(192)

Unified Diff: ash/common/wm/mru_window_tracker.h

Issue 2699033002: Replace WmWindowObserver with aura::WindowObserver. (Closed)
Patch Set: Check for null images in ShelfWindowWatcher. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/wm/maximize_mode/workspace_backdrop_delegate.cc ('k') | ash/common/wm/mru_window_tracker.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/wm/mru_window_tracker.h
diff --git a/ash/common/wm/mru_window_tracker.h b/ash/common/wm/mru_window_tracker.h
index ccf0a233d3e4dfc97c5ff349b97771567d1634b2..1c820e398fc7e9ec9ffeee2a420916b995f47ee5 100644
--- a/ash/common/wm/mru_window_tracker.h
+++ b/ash/common/wm/mru_window_tracker.h
@@ -10,8 +10,8 @@
#include "ash/ash_export.h"
#include "ash/common/wm_activation_observer.h"
-#include "ash/common/wm_window_observer.h"
#include "base/macros.h"
+#include "ui/aura/window_observer.h"
namespace ash {
@@ -20,7 +20,7 @@ class WmWindow;
// Maintains a most recently used list of windows. This is used for window
// cycling using Alt+Tab and overview mode.
class ASH_EXPORT MruWindowTracker : public WmActivationObserver,
- public WmWindowObserver {
+ public aura::WindowObserver {
public:
using WindowList = std::vector<WmWindow*>;
@@ -51,8 +51,8 @@ class ASH_EXPORT MruWindowTracker : public WmActivationObserver,
void OnWindowActivated(WmWindow* gained_active,
WmWindow* lost_active) override;
- // Overridden from WmWindowObserver:
- void OnWindowDestroyed(WmWindow* window) override;
+ // Overridden from aura::WindowObserver:
+ void OnWindowDestroyed(aura::Window* window) override;
// List of windows that have been activated in containers that we cycle
// through, sorted by most recently used.
« no previous file with comments | « ash/common/wm/maximize_mode/workspace_backdrop_delegate.cc ('k') | ash/common/wm/mru_window_tracker.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698